@@ -9,7 +9,7 @@
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-#        
+#
 # Khertan (Benoit HERVIER) khertan@khertan.net
 
 import sys
@@ -25,7 +25,7 @@ import commands
 import cPickle
 from subprocess import *
 from pge_buffer import SyntaxLoader,CodeBuffer
-import pge_preferences 
+import pge_preferences
 
 def is_space_or_tab(char,userdata):
   if (char==' ') or (char=='\t'):
@@ -51,26 +51,26 @@ class Editor (hildon.TextView):
     self.buffer=CodeBuffer(lang=lang)
     hildon.TextView.__init__ (self)
     self.set_buffer(self.buffer)
-    
+
     prefs = pge_preferences.Prefs()
     prefs.load()
     if prefs.prefs_dict['hildon_text_completion']==False:
       self.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_FULL)
 
     self.indent = prefs.prefs_dict['indent']
-    
+
     self.set_editable (True)
     self.no_edit_mode = True
     self.modify_font (pango.FontDescription (font_name+" "+str(font_size)))
     self.language = language
     self.searched_text = None
     self.expose_event_cb = None
-    
+
     if prefs.prefs_dict['show_lines'] == True:
       self.set_border_window_size(gtk.TEXT_WINDOW_LEFT, 30)
       self.line_view = self.get_window(gtk.TEXT_WINDOW_LEFT)
       self.expose_event_cb = self.connect("expose_event", self.line_numbers_expose)
-  
+
 #  def on_key_press(self, widget, event, *args):
 #    #CTRL-S : save
 #    if (event.keyval == gtk.keysyms.s) and (event.state==gtk.gdk.CONTROL_MASK):
@@ -97,14 +97,14 @@ class Editor (hildon.TextView):
       iter.forward_line()
 
     return count
-      
+
   def line_numbers_expose(self, widget, event, user_data=None):
     text_view = widget
 
     type = gtk.TEXT_WINDOW_LEFT
     target = text_view.get_window(gtk.TEXT_WINDOW_LEFT)
     target.set_background(gtk.gdk.Color(0,0,60000))
- 
+
     first_y = event.area.y
     last_y = first_y + event.area.height
 
@@ -119,7 +119,7 @@ class Editor (hildon.TextView):
 
     for i in range(count):
         x, pos = text_view.buffer_to_window_coords(type, 0, pixels[i])
-        str = '%d' % numbers[i]+1
+        str = '%d' % (numbers[i]+1)
         layout.set_text(str)
         widget.style.paint_layout(target, widget.state, False,
                                   None, widget, None, 2, pos + 2, layout)
@@ -188,7 +188,7 @@ class Editor (hildon.TextView):
       self.searched_text_count = 0
 
       start, end = buffer.get_bounds ()
-      
+
       buffer.remove_tag_by_name('search_hilight',start,end)
 
       self.search_results_list=[]
@@ -201,7 +201,7 @@ class Editor (hildon.TextView):
         buffer.apply_tag_by_name ("search_hilight", found_start, found_end)
         self.search_results_list.append(found_start.get_offset())
       buffer._apply_tags = False
-        
+
     else:
       self.searched_text_count =  self.searched_text_count + 1
     try:
@@ -212,7 +212,7 @@ class Editor (hildon.TextView):
       note = osso.SystemNote(self.get_parent().get_parent()._parent.context)
       result = note.system_note_infoprint("End text reached")
       self.searched_text_count = -1
-      
+
 
 
   #############################################################################
@@ -254,15 +254,15 @@ class Editor (hildon.TextView):
       start.set_line_offset(0)
       end.forward_to_line_end()
       insert = end.copy()
-      text = ''
+      text = buffer.get_text(start,end)
       if end.is_end():
-        text = '\n'
+        text = '\n'+text
         insert.forward_to_end()
       else:
+        text = text + '\n'
         insert.forward_line()
-      text = text+buffer.get_text(start,end)
       buffer.insert(insert,text)
-    
+
     else:
       insert = buffer.get_iter_at_mark(buffer.get_insert())
       start = buffer.get_iter_at_line(insert.get_line())
@@ -330,7 +330,7 @@ class Editor (hildon.TextView):
       return '--'
     else:
       return '//'
-      
+
   #############################################################################
   # @brief Remove space and tabs at end of line for all text in buffer
   #############################################################################
@@ -345,7 +345,7 @@ class Editor (hildon.TextView):
       if (start_delete_iter.get_char() != ' ') and (start_delete_iter.get_char() != '\t'):
         start_delete_iter.forward_char()
       buffer.delete(start_delete_iter,end_line_iter)
-      
+
   #############################################################################
   # @brief Comment / Uncomment
   #############################################################################
@@ -354,9 +354,9 @@ class Editor (hildon.TextView):
     if ctext != '':
       comment = True
       buffer = self.get_buffer()
-      r = buffer.get_iter_at_line(buffer.get_iter_at_mark(buffer.get_insert()).get_line()) 
+      r = buffer.get_iter_at_line(buffer.get_iter_at_mark(buffer.get_insert()).get_line())
       e=buffer.get_iter_at_offset(r.get_offset()+ len(ctext))
-      if (buffer.get_text(r,e)==ctext): 
+      if (buffer.get_text(r,e)==ctext):
         comment=False
       if comment==True:
         if (buffer.get_selection_bounds()!=()):
