@@ -10,7 +10,7 @@
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-#        
+#
 # Khertan (Benoit HERVIER) khertan@khertan.net
 
 import hildon
@@ -32,7 +32,7 @@ class Help(hildon.Window):
       self.rotation = FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.AUTOMATIC)
     else:
       self.rotation = FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.NEVER)
-    
+
     p = hildon.PannableArea()
     t = hildon.TextView()
     t.set_editable(False)
@@ -170,11 +170,15 @@ Roadmap :
 ◦ Link to bugtracker
 ◦ Implement autoclean space at end of line feature
 
+•Version 3.0.14 :
+◦ Fix duplicate multiple lines feature
+◦ Fix line number : #8814
+
 •Version 3.3.0 :
 ◦ Plugins
 ◦ Snippet
 """)
     p.add(t)
     self.add(p)
-    
+
     self.show_all()
